function [ A ] = construct_interval_structure( data, order )
% This file makes the data in better form by specifying data source and
% order of homology to your interest 
%
% Data 1 is the persistence intervals for 11 journals in math and
% engineering, where each journal has two networks, the one for 2004-2008,
% and the one for 2009-2013. data 2 is the networks for Transaction on
% Automatic Control, Transaction on Signal Processing, and Transaction on
% Wireless Communication. Use data to select the one of interest.
%
% Order can be either 0 or 1 or 2, indicating the persistence diagram we
% would like to compare
%
% Author: Weiyu Huang, whuang@seas.upenn.edu
% version 1
% 2017 Feb 17
% 
% References: W. Huang and A. Ribeiro, Persistent Homology Lower Bounds on
% High Order Network Distances, IEEE Transaction on Signal Processing, vol.
% 65, no. 2, pp. 319-334, January 2017.
%
% W. Huang and A. Ribeiro, Metrics in the Space of High Order Networks,
% IEEE Transaction on Signal Processing, vol. 64, no. 3, pp. 615-629,
% February 2016.


% load data
%
switch data
    case {'5Y', 1}
        data = load('5Y_persistence_intervals.mat');
    case {'ASW', 2}
        data = load('ASW_persistence_intervals');
end

% create interval sturcture
%
fields = fieldnames(data.PD);

% construct structure
%
A = cell(numel(fields), 1);

for i = 1:numel(fields)
    switch order
        case 0 % zeroth order
            A{i} = data.PD.(fields{i}).H0;
        case 1      % first order using H0 info
            A{i} = data.PD.(fields{i}).H1;
        case 2      % first order using H1 info
            A{i} = data.PD.(fields{i}).H2;
    end
end

end

