function m_distance_matrix = distance_matrix_bottleneck( A, threshold, flag )
% For each homological features in A, compute bottleneck distance between
% them, and forming a distance matrix represents pairwise distance.
% flag - whether Inf are kept. flag = 1, kept. flag = 0, remove;
%
% Author: Weiyu Huang, whuang@seas.upenn.edu
% version 1
% 2017 Feb 17
% 
% References: W. Huang and A. Ribeiro, Persistent Homology Lower Bounds on
% High Order Network Distances, IEEE Transaction on Signal Processing, vol.
% 65, no. 2, pp. 319-334, January 2017.
%
% W. Huang and A. Ribeiro, Metrics in the Space of High Order Networks,
% IEEE Transaction on Signal Processing, vol. 64, no. 3, pp. 615-629,
% February 2016.


m_distance_matrix = zeros(length(A));

for i = 1:length(A)
    for j = i+1:length(A)
        m_distance_matrix(i, j) = bottleneckPD_flag_simplify(A{i}, A{j}, threshold, flag);
        m_distance_matrix(j, i) = m_distance_matrix(i, j);
    end
end

end