% Script to draw Figure 11 in the paper Persistent Homology Lower Bounds
% on High Order Network Distances

% Author: Weiyu Huang, whuang@seas.upenn.edu
% version 1
% 2017 Feb 17
% 
% References: W. Huang and A. Ribeiro, Persistent Homology Lower Bounds on
% High Order Network Distances, IEEE Transaction on Signal Processing, vol.
% 65, no. 2, pp. 319-334, January 2017.
%
% W. Huang and A. Ribeiro, Metrics in the Space of High Order Networks,
% IEEE Transaction on Signal Processing, vol. 64, no. 3, pp. 615-629,
% February 2016.


%% script to examine difference start

load('5Y_persistence_intervals');

H0 = cell(22, 1); H1 = cell(22, 1); H2 = cell(22, 1);
H0_min = 1000; H1_min = 1000; H2_min = 1000;

fd = fieldnames(PD);

for i = 1:22
    H0{i} = PD.(fd{i}).H0; 
    H0_min = min(H0_min, length(H0{i}));
    H1{i} = PD.(fd{i}).H1;
    H1_min = min(H1_min, length(H1{i}));
    H2{i} = PD.(fd{i}).H2;
    H2_min = min(H2_min, length(H2{i}));
end

%% H0 birth

H0_birth = zeros(44, H0_min);

for i = 1:22
    temp = sort(H0{i}(:, 1), 'ascend') ./ 100;
    H0_birth(i, :) = temp(1:H0_min);
    temp = sort(H0{i}(:, 1), 'descend') ./ 100;
    H0_birth(i + 22, :) = temp(1:H0_min);
end

imagesc(H0_birth); colormap hot; colorbar;

%% H0 death

H0_birth = zeros(44, H0_min);

for i = 1:22
    temp = sort(H0{i}(:, 2), 'ascend') ./ 100;
    H0_birth(i, :) = temp(1:306);
    temp = sort(H0{i}(:, 2), 'descend') ./ 100;
    H0_birth(i + 22, :) = temp(1:306);
end

imagesc(H0_birth); colormap hot; colorbar;

%% H1 birth

H1_birth = zeros(44, H1_min);

for i = 1:22
    temp = sort(H1{i}(:, 1), 'ascend') ./ 100;
    H1_birth(i, :) = temp(1:H1_min);
    temp = sort(H1{i}(:, 1), 'descend') ./ 100;
    H1_birth(i + 22, :) = temp(1:H1_min);
end

imagesc(H1_birth); colormap hot; colorbar;

%% H1 death

H1_birth = zeros(44, H1_min);

for i = 1:22
    temp = sort(H1{i}(:, 2), 'ascend') ./ 100;
    H1_birth(i, :) = temp(1:H1_min);
    temp = sort(H1{i}(:, 2), 'descend') ./ 100;
    H1_birth(i + 22, :) = temp(1:H1_min);
end

imagesc(H1_birth); colormap hot; colorbar;

%% H2 birth

H2_birth = zeros(44, H2_min);

for i = 1:22
    temp = sort(H2{i}(:, 1), 'ascend') ./ 100;
    H2_birth(i, :) = temp(1:H2_min);
    temp = sort(H2{i}(:, 1), 'descend') ./ 100;
    H2_birth(i + 22, :) = temp(1:H2_min);
end

imagesc(H2_birth); colormap hot; colorbar;
