function [existence] = testPerfectMatching(G)
% testPerfectMatching test whether there exists a perfect matching given a
% matrix representing cost on path ij. Perfect matching exists only when all
% matchings have 0 cost.
%
% Author: Weiyu Huang, whuang@seas.upenn.edu
% version 1
% 2017 Feb 17
% 
% References: W. Huang and A. Ribeiro, Persistent Homology Lower Bounds on
% High Order Network Distances, IEEE Transaction on Signal Processing, vol.
% 65, no. 2, pp. 319-334, January 2017.
%
% W. Huang and A. Ribeiro, Metrics in the Space of High Order Networks,
% IEEE Transaction on Signal Processing, vol. 64, no. 3, pp. 615-629,
% February 2016.

K = 5; % number of iterations
m = sum(G(:) == 0); % number of 0 cost paths; 0s in bipartite graph
dim = length(G);

existence = 0; % initlaly set not existence

for k = 1:K
   A = zeros(dim);
   
   for  i = 1:dim
       for j = 1:dim
           if G(i,j) == 0
               A(i,j) = floor(m.^2 * rand(1));
           else
               A(i,j) = 0;
           end
       end
   end
   
   if rank(A) == dim
       existence = 1;
       return
   end
    
end

end

