function network = ER_weighted(n, p, threshold)
% generate a random network with n nodes, such that the edge weight between
% i and j is uniform between 0 and 1, each edge exists with probability p,
% and any edge with weights smaller than threshold is removed.
%
% Author: Weiyu Huang, whuang@seas.upenn.edu
% version 1
% 2017 Feb 17
% 
% References: W. Huang and A. Ribeiro, Persistent Homology Lower Bounds on
% High Order Network Distances, IEEE Transaction on Signal Processing, vol.
% 65, no. 2, pp. 319-334, January 2017.
%
% W. Huang and A. Ribeiro, Metrics in the Space of High Order Networks,
% IEEE Transaction on Signal Processing, vol. 64, no. 3, pp. 615-629,
% February 2016.

network = squareform( rand(n * (n-1) / 2, 1 ) );
network_p = squareform( rand(n * (n-1) / 2, 1 ) ) > p;
network = network .* network_p;

if threshold
    network = network .* (network > threshold);
end

end