function network = RBF(n, sigma, threshold)
% generate a random network with n nodes, such that the edge weight between
% i and j is exp(-d(i,j)^2 / (2 \sigma^2)). i and j are random points in
% the unit circles.
%
% Author: Weiyu Huang, whuang@seas.upenn.edu
% version 1
% 2017 Feb 17
% 
% References: W. Huang and A. Ribeiro, Persistent Homology Lower Bounds on
% High Order Network Distances, IEEE Transaction on Signal Processing, vol.
% 65, no. 2, pp. 319-334, January 2017.
%
% W. Huang and A. Ribeiro, Metrics in the Space of High Order Networks,
% IEEE Transaction on Signal Processing, vol. 64, no. 3, pp. 615-629,
% February 2016.

theta = rand(n, 1) * 2 * pi;
coordinates = [cos(theta), sin(theta)];

temp = pdist(coordinates);
if ~exist('sigma', 'var')
    sigma = 0.5;
end
network = squareform( exp(-temp.^2 / (2 * sigma)) );

if exist('threshold', 'var')
    network = network .* (network > threshold);
end

end