function [PH] = interval2Double( intervals)
% INTERVAL 2 DOUBLE: convert interval in
% edu.stanford.math.plex4.homology.barcodes.AnnotatedBarcodeCollection<T,G>
% format to 0-, 1-, 2- persistent homology group pairs in Matlab matrix
% form, if no PH in certain dimension, output = []
%
%   INPUT: intervals
%          max_filtration_value - normalized
%   OUTPUT: PH_0, PH_1, PH_2, 0-, 1-, 2- dimensional PH group pairs
%
% Author: Weiyu Huang, whuang@seas.upenn.edu
% version 1
% 2017 Feb 17
% 
% References: W. Huang and A. Ribeiro, Persistent Homology Lower Bounds on
% High Order Network Distances, IEEE Transaction on Signal Processing, vol.
% 65, no. 2, pp. 319-334, January 2017.
%
% W. Huang and A. Ribeiro, Metrics in the Space of High Order Networks,
% IEEE Transaction on Signal Processing, vol. 64, no. 3, pp. 615-629,
% February 2016.


% get intervals at three dimensions, in java.list format
i0_java = intervals.getIntervalsAtDimension(0); 
i1_java = intervals.getIntervalsAtDimension(1); 
i2_java = intervals.getIntervalsAtDimension(2); 

% convert to Matlab string format
i0 = char(i0_java);
i1 = char(i1_java);
i2 = char(i2_java);

% create PH, if empty, PH = []
if length(i0) == 2 % empty
    PH_0 = [];
else
    PH_0 = intervalIn1D2Double(i0);
end
if length(i1) == 2 % empty
    PH_1 = [];
else
    PH_1 = intervalIn1D2Double(i1);
end
if length(i2) == 2 % empty
    PH_2 = [];
else
    PH_2 = intervalIn1D2Double(i2);
end

PH = struct('H0', PH_0, 'H1', PH_1, 'H2', PH_2);

end

